@@ -4,17 +4,18 @@ use strict;
 use warnings;
 use 5.010001;
 use if !$INC{'File/HomeDir/Test.pm'}, 'File::HomeDir::Test';
+use Test2::API qw( context );
 use File::HomeDir;
 use Mojo::URL;
 use Mojo::Loader;
 use Mojo::UserAgent;
-use base qw( Test::Builder::Module );
 use Carp qw( croak carp );
 use File::Basename ();
 use File::Path ();
+use Test::Mojo;
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -62,7 +63,6 @@ sub new
 sub t {
   my($self) = @_;
   $self->{t} //= do {
-    require Test::Mojo;
     my $t = $self->{t} = Test::Mojo->new;
     $self->_update_default_server;
     $t;
@@ -248,6 +248,7 @@ sub create_cluster_ok
   my $self = shift;
 
   $self->_create_config_helper;
+  my $ctx = context();
   
   my $total = scalar @_;
   my @urls = map { 
@@ -426,9 +427,8 @@ sub create_cluster_ok
     $cb->() if defined $cb;
   }
 
-  my $tb = __PACKAGE__->builder;
-  $tb->ok(@errors == 0, "created cluster");
-  $tb->diag("exception: " . $_->[0] . ': ' . $_->[1]) for @errors;
+  $ctx->ok(@errors == 0, "created cluster");
+  $ctx->diag("exception: " . $_->[0] . ': ' . $_->[1]) for @errors;
   
   if($INC{'Clustericious/App.pm'})
   {
@@ -446,6 +446,7 @@ sub create_cluster_ok
     $self->_update_default_server;
   }
   
+  $ctx->release;
   return $self;
 }
 
@@ -454,7 +455,7 @@ sub create_plugauth_lite_ok
 {
   my($self, %args) = @_;
   my $ok = 1;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
   
   if(eval q{ use Clustericious; 1 } && ! eval q{ use Clustericious 0.9925; 1 })
   {
@@ -483,13 +484,14 @@ sub create_plugauth_lite_ok
     };
     if(my $error = $@)
     {
-      $tb->diag("error: $error");
+      $ctx->diag("error: $error");
       $ok = 0;
     }
   }
   
-  $tb->ok($ok, "PlugAuth::Lite instance on " . $self->{auth_url});
-  $tb->diag($_) for @diag;
+  $ctx->ok($ok, "PlugAuth::Lite instance on " . $self->{auth_url});
+  $ctx->diag($_) for @diag;
+  $ctx->release;
   
   return $self;
 }
@@ -499,7 +501,7 @@ sub stop_ok
 {
   my($self, $index, $test_name) = @_;
   my $ok = 1;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
   
   my $error;
   
@@ -529,9 +531,10 @@ sub stop_ok
   
   $test_name //= "stop service ($index)";
   
-  my $ret = $tb->ok($ok, $test_name);
+  my $ret = $ctx->ok($ok, $test_name);
   
-  $tb->diag($error) if $error;
+  $ctx->diag($error) if $error;
+  $ctx->release;
   
   $ret;
 }
@@ -541,7 +544,7 @@ sub start_ok
 {
   my($self, $index, $test_name) = @_;
   my $ok = 1;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
   
   my $error;
 
@@ -555,7 +558,7 @@ sub start_ok
     };
     if(my $error = $@)
     {
-      $tb->diag("error in start: $error");
+      $ctx->diag("error in start: $error");
       $ok = 0;
     }
 
@@ -575,11 +578,11 @@ sub start_ok
 
   $test_name //= "start service ($index)";
   
-  my $ret = $tb->ok($ok, $test_name);
-
-  $tb->diag($error) if $error;
-
-  $ret;
+  $ctx->ok($ok, $test_name);
+  $ctx->diag($error) if $error;
+  $ctx->release;
+  
+  $ok;
 }
 
 
@@ -591,8 +594,10 @@ sub is_stopped
   
   $test_name //= "servers ($index) is stopped";
   
-  my $tb = __PACKAGE__->builder;
-  $tb->ok($ok, $test_name);
+  my $ctx = context();
+  $ctx->ok($ok, $test_name);
+  $ctx->release;
+  $ok;
 }
 
 
@@ -604,8 +609,11 @@ sub isnt_stopped
   
   $test_name //= "servers ($index) is not stopped";
   
-  my $tb = __PACKAGE__->builder;
-  $tb->ok($ok, $test_name);
+  my $ctx = context();
+  $ctx->ok($ok, $test_name);
+  $ctx->release;
+  
+  $ok;
 }
 
 
@@ -630,7 +638,7 @@ sub extract_data_section
   $caller //= caller;
   my $all = Mojo::Loader::data_section $caller;
   my $home = File::HomeDir->my_home;
-  my $tb = __PACKAGE__->builder;
+  my $ctx = context();
 
   foreach my $name (keys %$all)
   {
@@ -641,18 +649,19 @@ sub extract_data_section
 
     unless(-d "$home/$dir")
     {
-      $tb->note("[extract] DIR  $home/$dir");
+      $ctx->note("[extract] DIR  $home/$dir");
       File::Path::mkpath "$home/$dir", 0, 0700;
     }
     unless(-f "$home/$dir/$basename")
     {
-      $tb->note("[extract] FILE $home/$dir/$basename");
+      $ctx->note("[extract] FILE $home/$dir/$basename");
       open my $fh, '>', "$home/$dir/$basename";
       print $fh $all->{$name};
       close $fh;
     }
   }
   
+  $ctx->release;
   $class;
 }
 
@@ -687,10 +696,11 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
+ use Test2::Bundle::More;
  use Test::Clustericious::Cluster;
  
  # suppose MyApp1 isa Clustericious::App and
@@ -704,6 +714,8 @@ version 0.33
  $t->get_ok("$url[0]/arbitrary_path");  # tests against MyApp1
  $t->get_ok("$url[1]/another_path");    # tests against MyApp2
  
+ done_testing;
+ 
  __DATA__
  
  @@ etc/MyApp1.conf
@@ -799,9 +811,13 @@ example that mocks parts of L<Net::hostent>:
  use strict;
  use warnings;
  use Test::Clustericious::Cluster;
- use Test::More tests => 2;
+ use Test2::Bundle::More;
+ 
+ plan 2;
+ 
+ eval q{ use Net::hostent };
+ is $@, '';
  
- use_ok('Net::hostent');
  is gethost('bar')->name, 'foo.example.com', 'gethost(bar).name = foo.example.com';
  
  __DATA__
@@ -954,11 +970,11 @@ For example:
  use strict;
  use warnings;
  use Test::Clustericious::Cluster;
- use Test::More;
+ use Test2::Bundle::More;
  BEGIN {
-   plan skip_all => 'test requires Clustericious 0.9925'
+   skip_all 'test requires Clustericious 0.9925'
      unless eval q{ use Clustericious 1.00; 1 };
-   plan skip_all => 'test requires PlugAuth::Lite'
+   skip_all 'test requires PlugAuth::Lite'
      unless eval q{ use PlugAuth::Lite 0.30; 1 };
  };
 
